Struct BlockBasedOptions

pub struct BlockBasedOptions { /* private fields */ }
For configuring block-based file storage.

Implementations

Source

impl BlockBasedOptions

pub fn set_block_size(&mut self, size: usize)

pub fn set_lru_cache(&mut self, size: size_t)

pub fn disable_cache(&mut self)

pub fn set_bloom_filter(&mut self, bits_per_key: c_int, block_based: bool)

pub fn set_cache_index_and_filter_blocks(&mut self, v: bool)

pub fn set_index_type(&mut self, index_type: BlockBasedIndexType)

Defines the index type to be used for SS-table lookups.

Example
use rocksdb::{BlockBasedOptions, BlockBasedIndexType, Options};

let mut opts = Options::default();
let mut block_opts = BlockBasedOptions::default();
block_opts.set_index_type(BlockBasedIndexType::HashSearch);
pub fn set_pin_l0_filter_and_index_blocks_in_cache(&mut self, v: bool)

If cache_index_and_filter_blocks is true and the below is true, then filter and index blocks are stored in the cache, but a reference is held in the “table reader” object so the blocks are pinned and only evicted from cache when the table reader is freed.

Default: false.

pub fn set_format_version(&mut self, version: i32)

Format version, reserved for backward compatibility. See https://github.com/facebook/rocksdb/blob/f059c7d9b96300091e07429a60f4ad55dac84859/include/rocksdb/table.h#L249-L274.

Default: 2.

pub fn set_block_restart_interval(&mut self, interval: i32)

Number of keys between restart points for delta encoding of keys. This parameter can be changed dynamically. Most clients should leave this parameter alone. The minimum value allowed is 1. Any smaller value will be silently overwritten with 1.

Default: 16.

pub fn set_index_block_restart_interval(&mut self, interval: i32)

Same as block_restart_interval but used for the index block. If you don’t plan to run RocksDB before version 5.16 and you are using index_block_restart_interval > 1, you should probably set the format_version to >= 4 as it would reduce the index size.

Default: 1.